#include <xc.h>

// Frequency definition
#define _XTAL_FREQ 4000000 

#define PWM_OUT   TRISCbits.TRISC5  
#define PWM_EN    TRISBbits.TRISB4
#define EN        PORTBbits.RB4

// PWM values list
const unsigned int pwm_values[] = {0,   100, 200,  300, 
                                   400, 500, 600,  700, 
                                   800, 900, 1023, 900, 
                                   800, 700, 600,  500,
                                   400, 300, 200,  100 };

void main(void) 
 { // Pin P1A as an output 
   PWM_OUT = 0;       
   PWM_EN  = 1;
   ANSELHbits.ANS10 = 0;
    
   // Configure CCP1 register for PWM
   CCP1CON = 0b00001100;
   // PWM period
   PR2 = 255;
    
   // Timer 2 configuration for PWM operation, 1:1 prescaler
   T2CON = 0b00000100;
   // Reset Timer2
   TMR2 = 0;
    
   // PWM initialization
   CCPR1L = 0;
   CCP1CONbits.DC1B = 0;
   
   // Simple gate based on RB4 pin logic level 
   while (!EN);
   
   // Change PWM from the list
   for(unsigned int i = 0; i < sizeof(pwm_values)/sizeof(pwm_values[0]); i++) 
    { // Set duty cycle value
      CCPR1L = pwm_values[i] >> 2;
      // Set duty cycle resolution bits      
      CCP1CONbits.DC1B = pwm_values[i] & 0x03;
      // PWM settling time      
      __delay_ms(10); 
    }
     
    // Stop PWM 
    CCP1CON = 0b00000000;    
    while(1) 
     {
     }
    
}
